@@ -1,4 +1,4 @@
-static const char rcsid[]="$Id: cat-compat.c,v 1.3 1998/10/15 20:34:51 roessler Exp $";
+static const char rcsid[]="$Id: cat-compat.c,v 1.5 2001/01/08 16:57:25 roessler Exp $";
 /* Compatibility code for gettext-using-catgets interface.
    Copyright (C) 1995, 1997 Free Software Foundation, Inc.
 
@@ -109,13 +109,13 @@ textdomain (domainname)
   if (new_name == NULL)
     return NULL;
 
-  strcpy (new_name, PACKAGE);
+  strcpy (new_name, PACKAGE);	/* __STRCPY_CHECKED__ */
   new_catalog = catopen (new_name, 0);
 
   if (new_catalog == (nl_catd) -1)
     {
       /* NLSPATH search didn't work, try absolute path */
-      sprintf (new_name, "%s/%s/LC_MESSAGES/%s.cat", LOCALEDIR, lang,
+      sprintf (new_name, "%s/%s/LC_MESSAGES/%s.cat", LOCALEDIR, lang, 	/* __SPRINTF_CHECKED__ - sort of... */
 	       PACKAGE);
       new_catalog = catopen (new_name, 0);
 
