@@ -501,6 +501,7 @@ typedef struct envelope
   char *date;
   char *x_label;
   LIST *references;		/* message references (in reverse order) */
+  LIST *in_reply_to;		/* in-reply-to header content */
   LIST *userhdrs;		/* user defined headers */
 } ENVELOPE;
 
@@ -774,6 +775,7 @@ typedef struct
 void state_prefix_putc(char, STATE *);
 int  state_printf(STATE *, const char *, ...);
 
+#include "ascii.h"
 #include "protos.h"
 #include "lib.h"
 #include "globals.h"
