@@ -146,7 +146,7 @@ static void pgp_current_time (STATE *s)
 }
 
 
-/* copy PGP output messages and look for signs of a good signature */
+/* Copy PGP output messages and look for signs of a good signature */
 
 static int pgp_copy_checksig (FILE *fpin, FILE *fpout)
 {
@@ -177,13 +177,81 @@ static int pgp_copy_checksig (FILE *fpin, FILE *fpout)
   return rv;
 }
 
+/* 
+ * Copy a clearsigned message, and strip the signature and PGP's
+ * dash-escaping.
+ */
+
+static long pgp_copy_clearsigned (STATE *s, long bytes)
+{
+  long last_pos, offset;
+  char buf[HUGE_STRING];
+  short complete, armor_header, have_sig;
+
+  last_pos = ftell (s->fpin);
+  
+  for (complete = 1, armor_header = 1, have_sig = 0;
+       bytes > 0 && fgets (buf, sizeof (buf), s->fpin) != NULL;  
+       complete = strchr (buf, '\n') != NULL)
+  {
+    offset   = ftell (s->fpin);
+    bytes   -= (offset - last_pos);
+    last_pos = offset;
+    
+    if (!complete)
+    {
+      if (!armor_header)
+	state_puts (buf, s);
+      continue;
+    }
+
+    if (mutt_strcmp (buf, "-----BEGIN PGP SIGNATURE-----\n") == 0)
+    {
+      have_sig = 1;
+      break;
+    }
+    
+    if (armor_header)
+    {
+      if (buf[0] == '\n') 
+	armor_header = 0;
+      continue;
+    }
+    
+    if (s->prefix) 
+      state_puts (s->prefix, s);
+    
+    if (buf[0] == '-' && buf[1] == ' ')
+      state_puts (buf + 2, s);
+    else
+      state_puts (buf, s);
+  }
+  
+  if (!have_sig)
+    return bytes;
+    
+  for (complete = 1;
+       bytes > 0 && fgets (buf, sizeof (buf), s->fpin) != NULL;
+       complete = strchr (buf, '\n') != NULL)
+  {
+    offset   = ftell (s->fpin);
+    bytes   -= (offset - last_pos);
+    last_pos = offset;
+    
+    if (mutt_strcmp (buf, "-----END PGP SIGNATURE-----\n") == 0)
+      break;
+  }
+  
+  return bytes;
+}
+
 
 /* Support for the Application/PGP Content Type. */
 
 void pgp_application_pgp_handler (BODY *m, STATE *s)
 {
   int needpass = -1, pgp_keyblock = 0;
-  int clearsign = 0, rv;
+  int clearsign = 0, rv, rc;
   long start_pos = 0;
   long bytes, last_pos, offset;
   char buf[HUGE_STRING];
@@ -203,6 +271,7 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
   {
     if (fgets (buf, sizeof (buf) - 1, s->fpin) == NULL)
       break;
+    
     offset = ftell (s->fpin);
     bytes -= (offset - last_pos); /* don't rely on mutt_strlen(buf) */
     last_pos = offset;
@@ -248,10 +317,10 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
 	}
 	
 	mutt_mktemp (tmpfname);
-	if ((tmpfp = safe_fopen(tmpfname, "w+")) == NULL)
+	if ((tmpfp = safe_fopen (tmpfname, "w+")) == NULL)
 	{
-	  mutt_perror(tmpfname);
-	  fclose(pgpout); pgpout = NULL;
+	  mutt_perror (tmpfname);
+	  safe_fclose (&pgpout); 
 	  return;
 	}
 	
@@ -270,7 +339,7 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
 	    break;
 	}
 
-	fclose(tmpfp);
+	safe_fclose (&tmpfp);
 	
 	if ((thepid = pgp_invoke_decode (&pgpin, NULL,
 					  &pgperr, -1,
@@ -300,14 +369,20 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
 	
 	rv = mutt_wait_filter (thepid);
 
-	mutt_unlink(tmpfname);
+	mutt_unlink (tmpfname);
 	
 	if (s->flags & M_DISPLAY)
-	  if (pgp_copy_checksig (pgperr, s->fpout) != 0 || rv != 0)
+	{
+	  rc = pgp_copy_checksig (pgperr, s->fpout);
+	  
+	  if (rc == 0)
+	    have_any_sigs = 1;
+	  if (rc || rv)
 	    maybe_goodsig = 0;
-	
+	}
+
 	safe_fclose (&pgperr);
-	
+
 	if (s->flags & M_DISPLAY)
 	  state_puts (_("\n[-- End of PGP output --]\n\n"), s);
       }
@@ -351,72 +426,12 @@ void pgp_application_pgp_handler (BODY *m, STATE *s)
       
       if(clearsign)
       {
-
-	/* rationale: We want PGP's error messages, but in the times
-	 * of PGP 5.0 we can't rely on PGP to do the dash
-	 * escape decoding - so we have to do this
-	 * ourselves.
-	 */
-	
-	int armor_header = 1;
-	int complete = 1;
-	
 	fseek(s->fpin, start_pos, SEEK_SET);
-	bytes += (last_pos - start_pos);
-	last_pos = start_pos;
-	offset = start_pos;
-	while(bytes > 0 && fgets(buf, sizeof(buf) - 1, s->fpin) != NULL)
-	{
-	  offset = ftell(s->fpin);
-	  bytes -= (offset - last_pos);
-	  last_pos = offset;
-
-	  if(complete)
-	  {
-	    if (!mutt_strcmp(buf, "-----BEGIN PGP SIGNATURE-----\n"))
-	      break;
-	    
-	    if(armor_header)
-	    {
-	      if(*buf == '\n')
-		armor_header = 0;
-	    }
-	    else
-	    {
-	      if(s->prefix)
-		state_puts(s->prefix, s);
-	      
-	      if(buf[0] == '-' && buf [1] == ' ')
-		state_puts(buf + 2, s);
-	      else
-		state_puts(buf, s);
-	    }
-	  } 
-	  else 
-	  {
-	    if(!armor_header)
-	      state_puts(buf, s);
-	  }
-	  
-	  complete = strchr(buf, '\n') != NULL;
-	}
-	
-	if (complete && !mutt_strcmp(buf, "-----BEGIN PGP SIGNATURE-----\n"))
-	{
-	  while(bytes > 0 && fgets(buf, sizeof(buf) - 1, s->fpin) != NULL)
-	  {
-	    offset = ftell(s->fpin);
-	    bytes -= (offset - last_pos);
-	    last_pos = offset;
-	    
-	    if(complete && !mutt_strcmp(buf, "-----END PGP SIGNATURE-----\n"))
-	      break;
-	    
-	    complete = strchr(buf, '\n') != NULL;
-	  }
-	}
+	bytes   += (last_pos - start_pos);
+	bytes    = pgp_copy_clearsigned (s, bytes);
+	last_pos = ftell (s->fpin);
       }
-      
+
       if (s->flags & M_DISPLAY)
       {
 	if (needpass)
@@ -519,10 +534,10 @@ int mutt_is_multipart_signed (BODY *b)
   char *p;
 
   if (!b || b->type != TYPEMULTIPART ||
-      !b->subtype || mutt_strcasecmp (b->subtype, "signed") ||
+      !b->subtype || ascii_strcasecmp (b->subtype, "signed") ||
       !(p = mutt_get_parameter ("protocol", b->parameter)) ||
-      (mutt_strcasecmp (p, "application/pgp-signature")
-      && mutt_strcasecmp (p, "multipart/mixed")))
+      (ascii_strcasecmp (p, "application/pgp-signature")
+      && ascii_strcasecmp (p, "multipart/mixed")))
     return 0;
 
   return PGPSIGN;
@@ -534,9 +549,9 @@ int mutt_is_multipart_encrypted (BODY *b)
   char *p;
   
   if (!b || b->type != TYPEMULTIPART ||
-      !b->subtype || mutt_strcasecmp (b->subtype, "encrypted") ||
+      !b->subtype || ascii_strcasecmp (b->subtype, "encrypted") ||
       !(p = mutt_get_parameter ("protocol", b->parameter)) ||
-      mutt_strcasecmp (p, "application/pgp-encrypted"))
+      ascii_strcasecmp (p, "application/pgp-encrypted"))
     return 0;
   
   return PGPENCRYPT;
@@ -549,23 +564,23 @@ int mutt_is_application_pgp (BODY *m)
   
   if (m->type == TYPEAPPLICATION)
   {
-    if (!mutt_strcasecmp (m->subtype, "pgp") || !mutt_strcasecmp (m->subtype, "x-pgp-message"))
+    if (!ascii_strcasecmp (m->subtype, "pgp") || !ascii_strcasecmp (m->subtype, "x-pgp-message"))
     {
       if ((p = mutt_get_parameter ("x-action", m->parameter))
-	  && (!mutt_strcasecmp (p, "sign") || !mutt_strcasecmp (p, "signclear")))
+	  && (!ascii_strcasecmp (p, "sign") || !ascii_strcasecmp (p, "signclear")))
 	t |= PGPSIGN;
 
       if ((p = mutt_get_parameter ("format", m->parameter)) && 
-	  !mutt_strcasecmp (p, "keys-only"))
+	  !ascii_strcasecmp (p, "keys-only"))
 	t |= PGPKEY;
 
       if(!t) t |= PGPENCRYPT;  /* not necessarily correct, but... */
     }
 
-    if (!mutt_strcasecmp (m->subtype, "pgp-signed"))
+    if (!ascii_strcasecmp (m->subtype, "pgp-signed"))
       t |= PGPSIGN;
 
-    if (!mutt_strcasecmp (m->subtype, "pgp-keys"))
+    if (!ascii_strcasecmp (m->subtype, "pgp-keys"))
       t |= PGPKEY;
   }
   return t;
@@ -577,8 +592,8 @@ int pgp_query (BODY *m)
 
   t |= mutt_is_application_pgp (m);
 
-  if ((t & PGPSIGN) && m->goodsig)
-    t |= PGPGOODSIGN;
+  if ((t & (PGPSIGN|PGPENCRYPT)) && m->goodsig)
+    t |= PGPGOODSIGN|PGPSIGN;
   else if (m->type == TYPEMULTIPART)
   {
     if (mutt_is_multipart_signed(m))
@@ -666,7 +681,8 @@ static int pgp_verify_one (BODY *sigbdy, STATE *s, const char *tempfile)
   FILE *fp, *pgpout, *pgperr;
   pid_t thepid;
   int badsig = -1;
-
+  int rv;
+  
   snprintf (sigfile, sizeof (sigfile), "%s.asc", tempfile);
   
   if(!(fp = safe_fopen (sigfile, "w")))
@@ -703,8 +719,10 @@ static int pgp_verify_one (BODY *sigbdy, STATE *s, const char *tempfile)
     mutt_copy_stream (pgperr, s->fpout);
     safe_fclose (&pgperr);
     
-    if (mutt_wait_filter (thepid))
+    if ((rv = mutt_wait_filter (thepid)))
       badsig = -1;
+    
+     dprint (1, (debugfile, "pgp_verify_one: mutt_wait_filter returned %d.\n", rv));
   }
   
   state_puts (_("[-- End of PGP output --]\n\n"), s);
@@ -753,15 +771,15 @@ void pgp_signed_handler (BODY *a, STATE *s)
   /* consistency check */
 
   if (!(a && a->next && a->next->type == protocol_major && 
-      !mutt_strcasecmp(a->next->subtype, protocol_minor)))
+      !ascii_strcasecmp(a->next->subtype, protocol_minor)))
   {
     state_puts(_("[-- Error: Inconsistent multipart/signed structure! --]\n\n"), s);
     mutt_body_handler (a, s);
     return;
   }
 
-  if(!(protocol_major == TYPEAPPLICATION && !mutt_strcasecmp(protocol_minor, "pgp-signature"))
-     && !(protocol_major == TYPEMULTIPART && !mutt_strcasecmp(protocol_minor, "mixed")))
+  if(!(protocol_major == TYPEAPPLICATION && !ascii_strcasecmp(protocol_minor, "pgp-signature"))
+     && !(protocol_major == TYPEMULTIPART && !ascii_strcasecmp(protocol_minor, "mixed")))
   {
     state_printf(s, _("[-- Error: Unknown multipart/signed protocol %s! --]\n\n"), protocol);
     mutt_body_handler (a, s);
@@ -781,7 +799,7 @@ void pgp_signed_handler (BODY *a, STATE *s)
 	for (i = 0; i < sigcnt; i++)
 	{
 	  if (signatures[i]->type == TYPEAPPLICATION 
-	      && !mutt_strcasecmp(signatures[i]->subtype, "pgp-signature"))
+	      && !ascii_strcasecmp(signatures[i]->subtype, "pgp-signature"))
 	  {
 	    if (pgp_verify_one (signatures[i], s, tempfile) != 0)
 	      goodsig = 0;
@@ -928,7 +946,7 @@ void pgp_extract_keys_from_attachment_list (FILE *fp, int tag, BODY *top)
   unset_option(OPTDONTHANDLEPGPKEYS);
 }
 
-BODY *pgp_decrypt_part (BODY *a, STATE *s, FILE *fpout)
+BODY *pgp_decrypt_part (BODY *a, STATE *s, FILE *fpout, BODY *p)
 {
   char buf[LONG_STRING];
   FILE *pgpin, *pgpout, *pgperr, *pgptmp;
@@ -997,7 +1015,8 @@ BODY *pgp_decrypt_part (BODY *a, STATE *s, FILE *fpout)
   {
     fflush (pgperr);
     rewind (pgperr);
-    mutt_copy_stream (pgperr, s->fpout);
+    if (pgp_copy_checksig (pgperr, s->fpout) == 0 && p)
+      p->goodsig = 1;
     state_puts (_("[-- End of PGP output --]\n\n"), s);
   }
   fclose (pgperr);
@@ -1024,6 +1043,7 @@ int pgp_decrypt_mime (FILE *fpin, FILE **fpout, BODY *b, BODY **cur)
 {
   char tempfile[_POSIX_PATH_MAX];
   STATE s;
+  BODY *p = b;
   
   if(!mutt_is_multipart_encrypted(b))
     return -1;
@@ -1043,7 +1063,7 @@ int pgp_decrypt_mime (FILE *fpin, FILE **fpout, BODY *b, BODY **cur)
   }
   unlink (tempfile);
 
-  *cur = pgp_decrypt_part (b, &s, *fpout);
+  *cur = pgp_decrypt_part (b, &s, *fpout, p);
 
   rewind (*fpout);
   return (0);
@@ -1054,12 +1074,13 @@ void pgp_encrypted_handler (BODY *a, STATE *s)
   char tempfile[_POSIX_PATH_MAX];
   FILE *fpout, *fpin;
   BODY *tattach;
-
+  BODY *p = a;
+  
   a = a->parts;
   if (!a || a->type != TYPEAPPLICATION || !a->subtype || 
-      mutt_strcasecmp ("pgp-encrypted", a->subtype) != 0 ||
+      ascii_strcasecmp ("pgp-encrypted", a->subtype) != 0 ||
       !a->next || a->next->type != TYPEAPPLICATION || !a->next->subtype ||
-      mutt_strcasecmp ("octet-stream", a->next->subtype) != 0)
+      ascii_strcasecmp ("octet-stream", a->next->subtype) != 0)
   {
     if (s->flags & M_DISPLAY)
       state_puts (_("[-- Error: malformed PGP/MIME message! --]\n\n"), s);
@@ -1081,7 +1102,7 @@ void pgp_encrypted_handler (BODY *a, STATE *s)
 
   if (s->flags & M_DISPLAY) pgp_current_time (s);
 
-  if ((tattach = pgp_decrypt_part (a, s, fpout)) != NULL)
+  if ((tattach = pgp_decrypt_part (a, s, fpout, p)) != NULL)
   {
     if (s->flags & M_DISPLAY)
       state_puts (_("[-- The following data is PGP/MIME encrypted --]\n\n"), s);
@@ -1099,7 +1120,7 @@ void pgp_encrypted_handler (BODY *a, STATE *s)
      */
     
     if (mutt_is_multipart_signed (tattach) && !tattach->next)
-      a->goodsig = tattach->goodsig;
+      p->goodsig |= tattach->goodsig;
     
     if (s->flags & M_DISPLAY)
       state_puts (_("\n[-- End of PGP/MIME encrypted data --]\n"), s);
@@ -1130,7 +1151,7 @@ static void convert_to_7bit (BODY *a)
 	convert_to_7bit (a->parts);
     } 
     else if (a->type == TYPEMESSAGE
-	     && mutt_strcasecmp(a->subtype, "delivery-status"))
+	     && ascii_strcasecmp(a->subtype, "delivery-status"))
     {
       if(a->encoding != ENC7BIT)
 	mutt_message_to_7bit(a, NULL);
@@ -1645,7 +1666,7 @@ int pgp_protect (HEADER *msg, char *pgpkeylist)
     return (-1);
 
   if ((msg->content->type == TYPETEXT) &&
-      !mutt_strcasecmp (msg->content->subtype, "plain") &&
+      !ascii_strcasecmp (msg->content->subtype, "plain") &&
       ((flags & PGPENCRYPT) || (msg->content->content && msg->content->content->hibin == 0)))
   {
     if ((i = query_quadoption (OPT_PGPTRADITIONAL, _("Create an application/pgp message?"))) == -1)
