@@ -129,7 +129,7 @@ static const char *pgp_entry_fmt (char *dest,
   pgp_entry_t *entry;
   pgp_uid_t *uid;
   pgp_key_t *key, *pkey;
-  int kflags;
+  int kflags = 0;
   int optional = (flags & M_FORMAT_OPTIONAL);
 
   entry = (pgp_entry_t *) data;
@@ -138,15 +138,12 @@ static const char *pgp_entry_fmt (char *dest,
   pkey  = pgp_principal_key (key);
 
   if (isupper (op))
-  {
     key = pkey;
-    kflags = pkey->flags;
-  }
-  else
-    /* a subkey inherits the principal key's usage restrictions. */
-    kflags = key->flags | (pkey->flags & KEYFLAG_RESTRICTIONS);
+
+  kflags = key->flags | (pkey->flags & KEYFLAG_RESTRICTIONS)
+    | uid->flags;
   
-  switch (tolower (op))
+  switch (ascii_tolower (op))
   {
     case '[':
 
@@ -304,8 +301,8 @@ static int _pgp_compare_address (const void *a, const void *b)
   if ((r = mutt_strcasecmp ((*s)->addr, (*t)->addr)))
     return r > 0;
   else
-    return (mutt_strcasecmp (pgp_keyid ((*s)->parent),
-			     pgp_keyid ((*t)->parent)) > 0);
+    return (mutt_strcasecmp (_pgp_keyid ((*s)->parent),
+			     _pgp_keyid ((*t)->parent)) > 0);
 }
 
 static int pgp_compare_address (const void *a, const void *b)
@@ -323,8 +320,8 @@ static int _pgp_compare_keyid (const void *a, const void *b)
   pgp_uid_t **s = (pgp_uid_t **) a;
   pgp_uid_t **t = (pgp_uid_t **) b;
 
-  if ((r = mutt_strcasecmp (pgp_keyid ((*s)->parent), 
-			    pgp_keyid ((*t)->parent))))
+  if ((r = mutt_strcasecmp (_pgp_keyid ((*s)->parent), 
+			    _pgp_keyid ((*t)->parent))))
     return r > 0;
   else
     return (mutt_strcasecmp ((*s)->addr, (*t)->addr)) > 0;
@@ -371,8 +368,8 @@ static int _pgp_compare_trust (const void *a, const void *b)
     return r < 0;
   if ((r = mutt_strcasecmp ((*s)->addr, (*t)->addr)))
     return r > 0;
-  return (mutt_strcasecmp (pgp_keyid ((*s)->parent), 
-			   pgp_keyid ((*t)->parent))) > 0;
+  return (mutt_strcasecmp (_pgp_keyid ((*s)->parent), 
+			   _pgp_keyid ((*t)->parent))) > 0;
 }
 
 static int pgp_compare_trust (const void *a, const void *b)
@@ -381,6 +378,63 @@ static int pgp_compare_trust (const void *a, const void *b)
 				       : _pgp_compare_trust (a, b));
 }
 
+static int pgp_key_is_valid (pgp_key_t *k)
+{
+  pgp_key_t *pk = pgp_principal_key (k);
+  if (k->flags & KEYFLAG_CANTUSE)
+    return 0;
+  if (pk->flags & KEYFLAG_CANTUSE)
+    return 0;
+  
+  return 1;
+}
+
+static int pgp_id_is_strong (pgp_uid_t *uid)
+{
+  if ((uid->trust & 3) < 3)
+    return 0;
+  /* else */
+  return 1;
+}
+
+static int pgp_id_is_valid (pgp_uid_t *uid)
+{
+  if (!pgp_key_is_valid (uid->parent))
+    return 0;
+  if (uid->flags & KEYFLAG_CANTUSE)
+    return 0;
+  /* else */
+  return 1;
+}
+
+#define PGP_KV_VALID  	1
+#define PGP_KV_ADDR   	2
+#define PGP_KV_STRING 	4
+#define PGP_KV_STRONGID 8
+
+#define PGP_KV_MATCH (PGP_KV_ADDR|PGP_KV_STRING)
+
+static int pgp_id_matches_addr (ADDRESS *addr, ADDRESS *u_addr, pgp_uid_t *uid)
+{
+  int rv = 0;
+  
+  if (pgp_id_is_valid (uid))
+    rv |= PGP_KV_VALID;
+
+  if (pgp_id_is_strong (uid))
+    rv |= PGP_KV_STRONGID;
+  
+  if (addr->mailbox && u_addr->mailbox
+      && mutt_strcasecmp (addr->mailbox, u_addr->mailbox) == 0)
+    rv |= PGP_KV_ADDR;
+    
+  if (addr->personal && u_addr->personal
+      && mutt_strcasecmp (addr->personal, u_addr->personal) == 0)
+    rv |= PGP_KV_STRING;
+  
+  return rv;
+}
+
 static pgp_key_t *pgp_select_key (pgp_key_t *keys,
 				  ADDRESS * p, const char *s)
 {
@@ -396,28 +450,42 @@ static pgp_key_t *pgp_select_key (pgp_key_t *keys,
   pgp_uid_t *a;
   int (*f) (const void *, const void *);
 
+  int unusable = 0;
+
+  keymax = 0;
+  KeyTable = NULL;
+
   for (i = 0, kp = keys; kp; kp = kp->next)
   {
     if (!option (OPTPGPSHOWUNUSABLE) && (kp->flags & KEYFLAG_CANTUSE))
+    {
+      unusable = 1;
       continue;
-    
-    for (a = kp->address; a; i++, a = a->next)
-      ;
+    }
+
+    for (a = kp->address; a; a = a->next)
+    {
+      if (!option (OPTPGPSHOWUNUSABLE) && (a->flags & KEYFLAG_CANTUSE))
+      {
+	unusable = 1;
+	continue;
+      }
+      
+      if (i == keymax)
+      {
+	keymax += 5;
+	safe_realloc ((void **) &KeyTable, sizeof (pgp_key_t *) * keymax);
+      }
+      
+      KeyTable[i++] = a;
+    }
   }
 
-  if (i == 0)
-    return NULL;
-
-  keymax = i;
-  KeyTable = safe_malloc (sizeof (pgp_key_t *) * i);
-
-  for (i = 0, kp = keys; kp; kp = kp->next)
+  if (!i && unusable)
   {
-    if (!option (OPTPGPSHOWUNUSABLE) && (kp->flags & KEYFLAG_CANTUSE))
-      continue;
-	
-    for (a = kp->address; a; i++, a = a->next)
-      KeyTable[i] = a;
+    mutt_error _("All matching keys are marked expired/revoked.");
+    sleep (1);
+    return NULL;
   }
 
   switch (PgpSortKeys & SORT_MASK)
@@ -450,7 +518,7 @@ static pgp_key_t *pgp_select_key (pgp_key_t *keys,
   strcat (helpstr, buf);	/* __STRCAT_CHECKED__ */
 
   menu = mutt_new_menu ();
-  menu->max = keymax;
+  menu->max = i;
   menu->make_entry = pgp_entry;
   menu->menu = MENU_PGP;
   menu->help = helpstr;
@@ -523,39 +591,35 @@ static pgp_key_t *pgp_select_key (pgp_key_t *keys,
       /* XXX make error reporting more verbose */
       
       if (option (OPTPGPCHECKTRUST))
-      {
-	pgp_key_t *key, *principal;
-	
-	key = KeyTable[menu->current]->parent;
-	principal = pgp_principal_key (key);
-	
-	if ((key->flags | principal->flags) & KEYFLAG_CANTUSE)
+	if (!pgp_key_is_valid (KeyTable[menu->current]->parent))
 	{
 	  mutt_error _("This key can't be used: expired/disabled/revoked.");
 	  break;
 	}
-      }
       
       if (option (OPTPGPCHECKTRUST) &&
-	  (KeyTable[menu->current]->trust & 0x03) < 3)
+	  (!pgp_id_is_valid (KeyTable[menu->current])
+	   || !pgp_id_is_strong (KeyTable[menu->current])))
       {
 	char *s = "";
 	char buff[LONG_STRING];
-
-	switch (KeyTable[menu->current]->trust & 0x03)
+	
+	if (KeyTable[menu->current]->flags & KEYFLAG_CANTUSE)
+	  s = N_("This ID is expired/disabled/revoked");
+	else switch (KeyTable[menu->current]->trust & 0x03)
 	{
-	case 0:
-	  s = N_("This ID's trust level is undefined.");
-	  break;
-	case 1:
-	  s = N_("This ID is not trusted.");
-	  break;
-	case 2:
-	  s = N_("This ID is only marginally trusted.");
-	  break;
+	  case 0:
+	    s = N_("This ID's trust level is undefined.");
+	    break;
+	  case 1:
+	    s = N_("This ID is not trusted.");
+	    break;
+	  case 2:
+	    s = N_("This ID is only marginally trusted.");
+	    break;
 	}
 
-	snprintf (buff, sizeof (buff), _("%s Do you really want to use it?"),
+	snprintf (buff, sizeof (buff), _("%s Do you really want to use the key?"),
 		  _(s));
 
 	if (mutt_yesorno (buff, 0) != 1)
@@ -596,6 +660,8 @@ pgp_key_t *pgp_ask_for_key (char *tag, char *whatfor,
   char resp[SHORT_STRING];
   struct pgp_cache *l = NULL;
 
+  mutt_clear_error ();
+  
   resp[0] = 0;
   if (whatfor)
   {
@@ -733,18 +799,33 @@ static LIST *pgp_add_string_to_hints (LIST *hints, const char *str)
   return hints;
 }
 
+static pgp_key_t **pgp_get_lastp (pgp_key_t *p)
+{
+  for (; p; p = p->next)
+    if (!p->next)
+      return &p->next;
+
+  return NULL;
+}
 
 pgp_key_t *pgp_getkeybyaddr (ADDRESS * a, short abilities, pgp_ring_t keyring)
 {
   ADDRESS *r, *p;
   LIST *hints = NULL;
-  int weak = 0;
-  int weak_association, kflags;
+
+  int weak    = 0;
+  int invalid = 0;
+  int multi   = 0;
+  int this_key_has_strong;
+  int this_key_has_weak;
+  int this_key_has_invalid;
   int match;
-  pgp_uid_t *q;
-  pgp_key_t *keys, *k, *kn, *pk;
+
+  pgp_key_t *keys, *k, *kn;
+  pgp_key_t *the_valid_key = NULL;
   pgp_key_t *matches = NULL;
   pgp_key_t **last = &matches;
+  pgp_uid_t *q;
   
   if (a && a->mailbox)
     hints = pgp_add_string_to_hints (hints, a->mailbox);
@@ -777,61 +858,51 @@ pgp_key_t *pgp_getkeybyaddr (ADDRESS * a, short abilities, pgp_ring_t keyring)
       continue;
     }
 
-    pk = pgp_principal_key (k);
-    kflags = k->flags | pk->flags;
-    
-    q = k->address;
-    weak_association = 1;
-    match = 0;
+    this_key_has_weak    = 0;	/* weak but valid match   */
+    this_key_has_invalid = 0;   /* invalid match          */
+    this_key_has_strong  = 0;	/* strong and valid match */
+    match                = 0;   /* any match 		  */
 
-    for (; q; q = q->next)
+    for (q = k->address; q; q = q->next)
     {
       r = rfc822_parse_adrlist (NULL, q->addr);
 
-
-      for (p = r; p && weak_association; p = p->next)
+      for (p = r; p; p = p->next)
       {
-	if ((p->mailbox && a->mailbox &&
-	     mutt_strcasecmp (p->mailbox, a->mailbox) == 0) ||
-	    (a->personal && p->personal &&
-	     mutt_strcasecmp (a->personal, p->personal) == 0))
-	{
+	int validity = pgp_id_matches_addr (a, p, q);
+
+	if (validity & PGP_KV_MATCH)	/* something matches */
 	  match = 1;
 
-	  if (((q->trust & 0x03) == 3) &&
-	      (!(kflags & KEYFLAG_CANTUSE)) &&
-	      (p->mailbox && a->mailbox &&
-	       !mutt_strcasecmp (p->mailbox, a->mailbox)))
-	  {
-	    weak_association = 0;
-	  }
+	/* is this key a strong candidate? */
+	if ((validity & PGP_KV_VALID) && (validity & PGP_KV_STRONGID) 
+	    && (validity & PGP_KV_ADDR))
+	{
+	  if (the_valid_key && the_valid_key != k)
+	    multi             = 1;
+	  the_valid_key       = k;
+	  this_key_has_strong = 1;
 	}
+	else if ((validity & PGP_KV_MATCH) && !(validity & PGP_KV_VALID))
+	  this_key_has_invalid = 1;
+	else if ((validity & PGP_KV_MATCH) 
+		 && (!(validity & PGP_KV_STRONGID) || !(validity & PGP_KV_ADDR)))
+	  this_key_has_weak    = 1;
       }
+
       rfc822_free_address (&r);
     }
 
-    if (match && weak_association)
-	weak = 1;
+    if (match && !this_key_has_strong && this_key_has_invalid)
+      invalid = 1;
+    if (match && !this_key_has_strong && this_key_has_weak)
+      weak = 1;
     
     if (match)
     {
-      pgp_key_t *_p, *_k;
-
-      _k = pgp_principal_key (k);
-      
-      *last = _k;
-      kn = pgp_remove_key (&keys, _k);
-
-      /* start with k, not with _k: k is always a successor of _k. */
-      
-      for (_p = k; _p; _p = _p->next)
-      {
-	if (!_p->next)
-	{
-	  last = &_p->next;
-	  break;
-	}
-      }
+      *last  = pgp_principal_key (k);
+      kn     = pgp_remove_key (&keys, *last);
+      last   = pgp_get_lastp (k);
     }
   }
 
@@ -839,18 +910,30 @@ pgp_key_t *pgp_getkeybyaddr (ADDRESS * a, short abilities, pgp_ring_t keyring)
   
   if (matches)
   {
-    if (matches->next || weak)
+    if (the_valid_key && !multi && !weak 
+	&& !(invalid && option (OPTPGPSHOWUNUSABLE)))
+    {	
+      /* 
+       * There was precisely one strong match on a valid ID, there
+       * were no valid keys with weak matches, and we aren't
+       * interested in seeing invalid keys.
+       * 
+       * Proceed without asking the user.
+       */
+      pgp_remove_key (&matches, the_valid_key);
+      pgp_free_key (&matches);
+      k = the_valid_key;
+    }
+    else 
     {
-      /* query for which key the user wants */
-      k = pgp_select_key (matches, a, NULL);
-      if (k) 
+      /* 
+       * Else: Ask the user.
+       */
+      if ((k = pgp_select_key (matches, a, NULL)))
 	pgp_remove_key (&matches, k);
-
       pgp_free_key (&matches);
     }
-    else
-      k = matches;
-    
+
     return k;
   }
 
@@ -903,23 +986,9 @@ pgp_key_t *pgp_getkeybystr (char *p, short abilities, pgp_ring_t keyring)
     
     if (match)
     {
-      pgp_key_t *_p, *_k;
-
-      _k = pgp_principal_key (k);
-      
-      *last = _k;
-      kn = pgp_remove_key (&keys, _k);
-
-      /* start with k, not with _k: k is always a successor of _k. */
-      
-      for (_p = k; _p; _p = _p->next)
-      {
-	if (!_p->next)
-	{
-	  last = &_p->next;
-	  break;
-	}
-      }
+      *last = pgp_principal_key (k);
+      kn    = pgp_remove_key (&keys, *last);
+      last  = pgp_get_lastp (k);
     }
   }
 
@@ -927,8 +996,7 @@ pgp_key_t *pgp_getkeybystr (char *p, short abilities, pgp_ring_t keyring)
 
   if (matches)
   {
-    k = pgp_select_key (matches, NULL, p);
-    if (k) 
+    if ((k = pgp_select_key (matches, NULL, p)))
       pgp_remove_key (&matches, k);
     
     pgp_free_key (&matches);
