@@ -52,6 +52,8 @@ extern int optind;
 #include "sha1.h"
 #include "lib.h"
 #include "pgplib.h"
+#include "pgppacket.h"
+
 
 #ifdef HAVE_FGETPOS
 #define FGETPOS(fp,pos) fgetpos((fp),&(pos))
@@ -61,10 +63,7 @@ extern int optind;
 #define FSETPOS(fp,pos) fseek((fp),(pos),SEEK_SET)
 #endif
 
-#define CHUNKSIZE 1024
 
-static unsigned char *pbuf = NULL;
-static size_t plen = 0;
 
 static void pgpring_find_candidates (char *ringfile, const char *hints[], int nhints);
 static void pgpring_dump_keyblock (pgp_key_t *p);
@@ -141,243 +140,6 @@ int main (int argc, char * const argv[])
 
 /* The actual key ring parser */
 
-enum packet_tags
-{
-  PT_RES0 = 0,			/* reserved */
-  PT_ESK,			/* Encrypted Session Key */
-  PT_SIG,			/* Signature Packet */
-  PT_CESK,			/* Conventionally Encrypted Session Key Packet */
-  PT_OPS,			/* One-Pass Signature Packet */
-  PT_SECKEY,			/* Secret Key Packet */
-  PT_PUBKEY,			/* Public Key Packet */
-  PT_SUBSECKEY,			/* Secret Subkey Packet */
-  PT_COMPRESSED,		/* Compressed Data Packet */
-  PT_SKE,			/* Symmetrically Encrypted Data Packet */
-  PT_MARKER,			/* Marker Packet */
-  PT_LITERAL,			/* Literal Data Packet */
-  PT_TRUST,			/* Trust Packet */
-  PT_NAME,			/* Name Packet */
-  PT_SUBKEY,			/* Subkey Packet */
-  PT_RES15,			/* Reserved */
-  PT_COMMENT			/* Comment Packet */
-};
-
-/* 
- * These aren't displayed at all currently, but they may come quite
- * handy for debugging strings.
- * 
- * No need to translate them.
- *
- */
-
-#if 0
-
-const char *pgp_packet_name[] =
-{
-  "reserved",
-  "Encrypted Session Key",
-  "Signature Packet",
-  "Conventionally Encrypted Session Key Packet",
-  "One-Pass Signature Packet",
-  "Secret Key Packet",
-  "Public Key Packet",
-  "Secret Subkey Packet",
-  "Compressed Data Packet",
-  "Symmetrically Encrypted Data Packet",
-  "Marker Packet",
-  "Literal Data Packet",
-  "Trust Packet",
-  "Name Packet",
-  "Subkey Packet",
-  "Reserved",
-  "Comment Packet"
-};
-
-#endif
-
-static int read_material (size_t material, size_t * used, FILE * fp)
-{
-  if (*used + material >= plen)
-  {
-    unsigned char *p;
-    size_t nplen;
-
-    nplen = *used + material + CHUNKSIZE;
-
-    if (!(p = realloc (pbuf, nplen)))	/* __MEM_CHECKED__ */
-    {
-      perror ("realloc");
-      return -1;
-    }
-    plen = nplen;
-    pbuf = p;
-  }
-
-  if (fread (pbuf + *used, 1, material, fp) < material)
-  {
-    perror ("fread");
-    return -1;
-  }
-
-  *used += material;
-  return 0;
-}
-
-static unsigned char *pgp_read_packet (FILE * fp, size_t * len)
-{
-  size_t used = 0;
-  long startpos;
-  unsigned char ctb;
-  unsigned char b;
-  size_t material;
-
-  startpos = ftell (fp);
-
-  if (!plen)
-  {
-    plen = CHUNKSIZE;
-    pbuf = safe_malloc (plen);
-  }
-
-  if (fread (&ctb, 1, 1, fp) < 1)
-  {
-    if (!feof (fp))
-      perror ("fread");
-    goto bail;
-  }
-
-  if (!(ctb & 0x80))
-  {
-    goto bail;
-  }
-
-  if (ctb & 0x40)		/* handle PGP 5.0 packets. */
-  {
-    int partial = 0;
-    pbuf[0] = ctb;
-    used++;
-
-    do
-    {
-      if (fread (&b, 1, 1, fp) < 1)
-      {
-	perror ("fread");
-	goto bail;
-      }
-
-      if (b < 192)
-      {
-	material = b;
-	partial = 0;
-	material -= 1;
-      }
-      else if (192 <= b && b <= 223)
-      {
-	material = (b - 192) * 256;
-	if (fread (&b, 1, 1, fp) < 1)
-	{
-	  perror ("fread");
-	  goto bail;
-	}
-	material += b + 192;
-	partial = 0;
-	material -= 2;
-      }
-      else if (b < 255)
-      {
-	material = 1 << (b & 0x1f);
-	partial = 1;
-	material -= 1;
-      }
-      else
-	/* b == 255 */
-      {
-	unsigned char buf[4];
-	if (fread (buf, 4, 1, fp) < 1)
-	{
-	  perror ("fread");
-	  goto bail;
-	}
-	/*assert( sizeof(material) >= 4 ); */
-	material = buf[0] << 24;
-	material |= buf[1] << 16;
-	material |= buf[2] << 8;
-	material |= buf[3];
-	partial = 0;
-	material -= 5;
-      }
-
-      if (read_material (material, &used, fp) == -1)
-	goto bail;
-
-    }
-    while (partial);
-  }
-  else
-    /* Old-Style PGP */
-  {
-    int bytes = 0;
-    pbuf[0] = 0x80 | ((ctb >> 2) & 0x0f);
-    used++;
-
-    switch (ctb & 0x03)
-    {
-      case 0:
-      {
-	if (fread (&b, 1, 1, fp) < 1)
-	{
-	  perror ("fread");
-	  goto bail;
-	}
-
-	material = b;
-	break;
-      }
-
-      case 1:
-      bytes = 2;
-
-      case 2:
-      {
-	int i;
-
-	if (!bytes)
-	  bytes = 4;
-
-	material = 0;
-
-	for (i = 0; i < bytes; i++)
-	{
-	  if (fread (&b, 1, 1, fp) < 1)
-	  {
-	    perror ("fread");
-	    goto bail;
-	  }
-
-	  material = (material << 8) + b;
-	}
-	break;
-      }
-
-      default:
-      goto bail;
-    }
-
-    if (read_material (material, &used, fp) == -1)
-      goto bail;
-  }
-
-  if (len)
-    *len = used;
-
-  return pbuf;
-
-bail:
-
-  fseek (fp, startpos, SEEK_SET);
-  return NULL;
-}
-
 static pgp_key_t *pgp_parse_pgp2_key (unsigned char *buff, size_t l)
 {
   pgp_key_t *p;
