@@ -67,7 +67,7 @@ static int mutt_addrcmp (ADDRESS *a, ADDRESS *b)
 {
   if (!a->mailbox || !b->mailbox)
     return 0;
-  if (mutt_strcasecmp (a->mailbox, b->mailbox))
+  if (ascii_strcasecmp (a->mailbox, b->mailbox))
     return 0;
   return 1;
 }
@@ -222,7 +222,7 @@ static int edit_envelope (ENVELOPE *en)
     buf[0] = 0;
     for (; uh; uh = uh->next)
     {
-      if (mutt_strncasecmp ("subject:", uh->data, 8) == 0)
+      if (ascii_strncasecmp ("subject:", uh->data, 8) == 0)
       {
 	p = uh->data + 8;
 	SKIPWS (p);
@@ -248,11 +248,11 @@ static void process_user_recips (ENVELOPE *env)
 
   for (; uh; uh = uh->next)
   {
-    if (mutt_strncasecmp ("to:", uh->data, 3) == 0)
+    if (ascii_strncasecmp ("to:", uh->data, 3) == 0)
       env->to = rfc822_parse_adrlist (env->to, uh->data + 3);
-    else if (mutt_strncasecmp ("cc:", uh->data, 3) == 0)
+    else if (ascii_strncasecmp ("cc:", uh->data, 3) == 0)
       env->cc = rfc822_parse_adrlist (env->cc, uh->data + 3);
-    else if (mutt_strncasecmp ("bcc:", uh->data, 4) == 0)
+    else if (ascii_strncasecmp ("bcc:", uh->data, 4) == 0)
       env->bcc = rfc822_parse_adrlist (env->bcc, uh->data + 4);
   }
 }
@@ -268,23 +268,23 @@ static void process_user_header (ENVELOPE *env)
 
   for (; uh; uh = uh->next)
   {
-    if (mutt_strncasecmp ("from:", uh->data, 5) == 0)
+    if (ascii_strncasecmp ("from:", uh->data, 5) == 0)
     {
       /* User has specified a default From: address.  Remove default address */
       rfc822_free_address (&env->from);
       env->from = rfc822_parse_adrlist (env->from, uh->data + 5);
     }
-    else if (mutt_strncasecmp ("reply-to:", uh->data, 9) == 0)
+    else if (ascii_strncasecmp ("reply-to:", uh->data, 9) == 0)
     {
       rfc822_free_address (&env->reply_to);
       env->reply_to = rfc822_parse_adrlist (env->reply_to, uh->data + 9);
     }
-    else if (mutt_strncasecmp ("message-id:", uh->data, 11) == 0)
+    else if (ascii_strncasecmp ("message-id:", uh->data, 11) == 0)
       mutt_str_replace (&env->message_id, uh->data + 11);
-    else if (mutt_strncasecmp ("to:", uh->data, 3) != 0 &&
-	     mutt_strncasecmp ("cc:", uh->data, 3) != 0 &&
-	     mutt_strncasecmp ("bcc:", uh->data, 4) != 0 &&
-	     mutt_strncasecmp ("subject:", uh->data, 8) != 0)
+    else if (ascii_strncasecmp ("to:", uh->data, 3) != 0 &&
+	     ascii_strncasecmp ("cc:", uh->data, 3) != 0 &&
+	     ascii_strncasecmp ("bcc:", uh->data, 4) != 0 &&
+	     ascii_strncasecmp ("subject:", uh->data, 8) != 0)
     {
       if (last)
       {
@@ -586,9 +586,6 @@ void mutt_make_forward_subject (ENVELOPE *env, CONTEXT *ctx, HEADER *cur)
 void mutt_make_misc_reply_headers (ENVELOPE *env, CONTEXT *ctx,
 				    HEADER *cur, ENVELOPE *curenv)
 {
-  LIST *tmp;
-  char buffer[STRING];
-
   if (curenv->real_subj)
   {
     env->subject = safe_malloc (mutt_strlen (curenv->real_subj) + 5);
@@ -597,22 +594,44 @@ void mutt_make_misc_reply_headers (ENVELOPE *env, CONTEXT *ctx,
   else
     env->subject = safe_strdup ("Re: your mail");
   
-  /* add the In-Reply-To field */
-  if (InReplyTo)
+}
+
+static void 
+mutt_make_reference_headers (ENVELOPE *curenv, ENVELOPE *env, CONTEXT *ctx)
+{
+  HEADER *h;
+  LIST **p, **q;
+  int i;
+  
+  if (!curenv)
   {
-    strfcpy (buffer, "In-Reply-To: ", sizeof (buffer));
-    mutt_make_string (buffer + 13, sizeof (buffer) - 13, InReplyTo, ctx, cur);
-    tmp = env->userhdrs;
-    while (tmp && tmp->next)
-      tmp = tmp->next;
-    if (tmp)
+    env->references = NULL;
+    env->in_reply_to = NULL;
+    p = &env->references;
+    q = &env->in_reply_to;
+    
+    for(i = 0; i < ctx->vcount; i++)
     {
-      tmp->next = mutt_new_list ();
-      tmp = tmp->next;
+      while(*p) p = &(*p)->next;
+      while (*q) q = &(*q)->next;
+      
+      h = ctx->hdrs[ctx->v2r[i]];
+      if(h->tagged)
+      {
+	*p = mutt_make_references(h->env);
+	if (h->env->message_id)
+	{
+	  *q = mutt_new_list ();
+	  (*q)->data = safe_strdup (h->env->message_id);
+	}
+      }
     }
-    else
-      tmp = env->userhdrs = mutt_new_list ();
-    tmp->data = safe_strdup (buffer);
+  }
+  else
+  {
+    env->references = mutt_make_references (curenv);
+    env->in_reply_to = mutt_new_list ();
+    env->in_reply_to->data = safe_strdup (curenv->message_id);
   }
 }
 
@@ -669,26 +688,7 @@ envelope_defaults (ENVELOPE *env, CONTEXT *ctx, HEADER *cur, int flags)
 
     mutt_fix_reply_recipients (env);
     mutt_make_misc_reply_headers (env, ctx, cur, curenv);
-    
-    if(tag)
-    {
-      HEADER *h;
-      LIST **p;
-
-      env->references = NULL;
-      p = &env->references;
-
-      for(i = 0; i < ctx->vcount; i++)
-      {
-	while(*p) p = &(*p)->next;
-	h = ctx->hdrs[ctx->v2r[i]];
-	if(h->tagged)
-	  *p = mutt_make_references(h->env);
-      }
-    }
-    else
-      env->references = mutt_make_references(curenv);
-
+    mutt_make_reference_headers (tag ? NULL : curenv, env, ctx);
   }
   else if (flags & SENDFORWARD)
     mutt_make_forward_subject (env, ctx, cur);
@@ -1008,6 +1008,46 @@ int mutt_resend_message (FILE *fp, CONTEXT *ctx, HEADER *cur)
   return ci_send_message (SENDRESEND, msg, NULL, ctx, cur);
 }
 
+#ifdef HAVE_PGP
+
+static int _set_pgp_flags (HEADER *cur)
+{
+  int flags = 0;
+  
+  if (option (OPTPGPREPLYENCRYPT) && cur && cur->pgp & PGPENCRYPT)
+    flags |= PGPENCRYPT;
+  if (option (OPTPGPREPLYSIGN) && cur && cur->pgp & PGPSIGN)
+    flags |= PGPSIGN;
+  if (option (OPTPGPREPLYSIGNENCRYPTED) && cur && cur->pgp & PGPENCRYPT)
+    flags |= PGPSIGN;
+
+  return flags;
+
+}
+
+static int set_pgp_flags (HEADER *cur, CONTEXT *ctx)
+{
+  int i;
+  int flags = 0;
+  
+  if (cur) 
+    return _set_pgp_flags (cur);
+  
+  if (!ctx)
+    return 0;
+    
+  for (i = 0; i < ctx->vcount; i++)
+  {
+    cur = ctx->hdrs[ctx->v2r[i]];
+    if (cur->tagged)
+      flags |= _set_pgp_flags (cur);
+  }
+
+  return flags;
+}
+
+#endif /* HAVE_PGP */
+
 int
 ci_send_message (int flags,		/* send mode */
 		 HEADER *msg,		/* template to use for new message */
@@ -1196,14 +1236,12 @@ ci_send_message (int flags,		/* send mode */
 	msg->pgp |= PGPSIGN;
       if (option (OPTPGPAUTOENCRYPT))
 	msg->pgp |= PGPENCRYPT;
-      if (option (OPTPGPREPLYENCRYPT) && cur && cur->pgp & PGPENCRYPT)
-	msg->pgp |= PGPENCRYPT;
-      if (option (OPTPGPREPLYSIGN) && cur && cur->pgp & PGPSIGN)
-	msg->pgp |= PGPSIGN;
-      if (option (OPTPGPREPLYSIGNENCRYPTED) && cur && cur->pgp & PGPENCRYPT)
-	msg->pgp |= PGPSIGN;
+      
+      msg->pgp |= set_pgp_flags (cur, ctx);
     }
+
 #endif /* HAVE_PGP */
+      
 
 
 
